summaryrefslogtreecommitdiff
path: root/test/files
diff options
context:
space:
mode:
authorLukas Rytz <lukas.rytz@typesafe.com>2016-04-22 08:36:11 +0200
committerLukas Rytz <lukas.rytz@typesafe.com>2016-04-22 08:36:11 +0200
commit6863c5c390d59f4ccee4f1b877479128a8682820 (patch)
tree6250c816c8a751dd8db0a92f137ce1856e39fca7 /test/files
parent7a24bd6bcde707e25b17e8e1f8dcdea21c51e17a (diff)
parentcce701650143d13c8b292bffd590bf7c8eb532d7 (diff)
downloadscala-6863c5c390d59f4ccee4f1b877479128a8682820.tar.gz
scala-6863c5c390d59f4ccee4f1b877479128a8682820.tar.bz2
scala-6863c5c390d59f4ccee4f1b877479128a8682820.zip
Merge pull request #5110 from sjrd/remove-duplicate-implem-of-hashcodes
Remove the duplicate implem of hash codes for numbers.
Diffstat (limited to 'test/files')
-rw-r--r--test/files/run/equality.scala2
-rw-r--r--test/files/run/hashCodeStatics.scala (renamed from test/files/run/hashCodeBoxesRunTime.scala)11
2 files changed, 6 insertions, 7 deletions
diff --git a/test/files/run/equality.scala b/test/files/run/equality.scala
index ff59898821..2af73691d8 100644
--- a/test/files/run/equality.scala
+++ b/test/files/run/equality.scala
@@ -1,7 +1,7 @@
// a quickly assembled test of equality. Needs work.
object Test
{
- import scala.runtime.ScalaRunTime.hash
+ def hash(x: Any): Int = x.## // forces upcast to Any
def makeFromInt(x: Int) = List(
x.toByte, x.toShort, x.toInt, x.toLong, x.toFloat, x.toDouble, BigInt(x), BigDecimal(x)
diff --git a/test/files/run/hashCodeBoxesRunTime.scala b/test/files/run/hashCodeStatics.scala
index 8ad94c252a..bff62cce18 100644
--- a/test/files/run/hashCodeBoxesRunTime.scala
+++ b/test/files/run/hashCodeStatics.scala
@@ -1,24 +1,23 @@
// This only tests direct access to the methods in BoxesRunTime,
// not the whole scheme.
object Test
{
import java.{ lang => jl }
- import scala.runtime.BoxesRunTime.hashFromNumber
- import scala.runtime.ScalaRunTime.{ hash => hashFromAny }
+ import scala.runtime.Statics.anyHash
def allSame[T](xs: List[T]) = assert(xs.distinct.size == 1, "failed: " + xs)
def mkNumbers(x: Int): List[Number] =
List(x.toByte, x.toShort, x, x.toLong, x.toFloat, x.toDouble)
- def testLDF(x: Long) = allSame(List[Number](x, x.toDouble, x.toFloat) map hashFromNumber)
+ def testLDF(x: Long) = allSame(List[Number](x, x.toDouble, x.toFloat) map anyHash)
def main(args: Array[String]): Unit = {
List(Byte.MinValue, -1, 0, 1, Byte.MaxValue) foreach { n =>
- val hashes = mkNumbers(n) map hashFromNumber
+ val hashes = mkNumbers(n) map anyHash
allSame(hashes)
if (n >= 0) {
- val charCode = hashFromAny(n.toChar: Character)
+ val charCode = anyHash(n.toChar: Character)
assert(charCode == hashes.head)
}
}
@@ -1,24 +1,23 @@
-// This only tests direct access to the methods in BoxesRunTime,
+// This only tests direct access to the methods in Statics,
// not the whole scheme.
object Test